multicraft-backup
=================

.. image:: https://img.shields.io/pypi/v/multicraft-backup.svg
	:target: https://pypi.python.org/pypi/multicraft-backup
	:alt: Latest PyPI version

Backs up your Minecraft servers from hosts that use Multicraft

Usage
-----

Installation
------------

Requirements
^^^^^^^^^^^^

Compatibility
-------------

Licence
-------

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; version 2
of the License only.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.


Authors
-------

`multicraft-backup` was written by `Benjamin Mintz <bmintz@protonmail.com>`_.
